﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using MapObjects;

namespace Cameras
{
    /// <summary>
    /// This class represent a 3D camera.
    /// </summary>
    public class Camera
    {
        #region Variables

        // Camera view and projection.
        public Matrix view;
        public Matrix projection;

        // Camera position variables
        public Vector3 cameraPosition;
        public Vector3 cameraUp;
        public float cameraHeightOverPlayerFeets = 50;
        public const byte CAMERA_OFFSET = 4;
        public float fieldOfView = MathHelper.ToRadians(60f); // 60

        #endregion

        #region Constructors

        /// <summary>
        /// Create a new camera.
        /// </summary>
        /// <param name="content"></param>
        /// <param name="position"></param>
        /// <param name="target"></param>
        /// <param name="up"></param>
        /// <param name="graphicsDevice"></param>
        public Camera(Vector3 playerPosition, Vector3 PlayerDirection)
        {
            // Set values for instance variables
            this.cameraPosition = playerPosition - (PlayerDirection * CAMERA_OFFSET);
            this.cameraUp = Vector3.Up;

        } // End of the constructor

        #endregion

        #region Methods

        /// <summary>
        /// Update the camera
        /// </summary>
        /// <param name="playerPosition"></param>
        /// <param name="playerDirection"></param>
        /// <param name="cameraTarget"></param>
        /// <param name="viewPort"></param>
        public void Update(Vector3 playerPosition, Vector3 playerDirection, Vector3 cameraTarget, Viewport viewPort)
        {
            // Set the camera position as a offset from the player position
            this.cameraPosition = playerPosition - (playerDirection * CAMERA_OFFSET);
            this.cameraPosition.Y += this.cameraHeightOverPlayerFeets;

            // Create a new view matrix.
            this.view = Matrix.CreateLookAt(this.cameraPosition, this.cameraPosition + cameraTarget, this.cameraUp);

            // Create a new perspective projection matrix
            this.projection = Matrix.CreatePerspectiveFieldOfView(this.fieldOfView, (float)viewPort.Width /
                ((float)viewPort.Height), 1, 1000); // 1 to 3000

        } // End of the Update method

        #endregion

    } // End of the class

} // End of the namespace
