using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Media;
using AvatarBlockWar.Screens.MenuScreens;
using ScreenManagement;
using Networking;

namespace AvatarBlockWar
{
    /// <summary>
    /// This class represent the game engine for this game.
    /// </summary>
    public class GameEngine : Microsoft.Xna.Framework.Game
    {
        #region Variables

        // A graphics device manager to be able to draw to the screen.
        GraphicsDeviceManager graphics;

        // Handles menu screens (screenManager is a game component)
        ScreenManager screenManager;

        // Measure the framerate.
        public static int frameRate;
        public int frameCounter;
        public TimeSpan elapsedTime;

        #endregion

        #region Constructors

        /// <summary>
        /// Create a new game engine
        /// </summary>
        public GameEngine()
        {

            // Create a graphics device manager and a content manager
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            // Measure framerate (Not on Xbox 360)
            //IsFixedTimeStep = false;
            //graphics.SynchronizeWithVerticalRetrace = false;

            // Set the resolution
            graphics.PreferredBackBufferWidth = 1280;
            graphics.PreferredBackBufferHeight = 720;
            //graphics.PreferMultiSampling = true; // This setting will lower the framerate substantially

            // Set the window title
            Window.Title = "Avatar Block War";

            // Create game components.
            screenManager = new ScreenManager(this);
            Components.Add(screenManager);
            Components.Add(new MessageDisplayComponent(this));
            Components.Add(new GamerServicesComponent(this));

            // Add the splash screen.
            //screenManager.AddScreen(new SplashScreen(), null);

            // Add the menu screens
            screenManager.AddScreen(new BackgroundScreen(), null);
            screenManager.AddScreen(new MainMenuScreen(), null);

            // Listen for invite notification events.
            NetworkSession.InviteAccepted += (sender, e) => NetworkSessionComponent.InviteAccepted(screenManager, e);

            // To test the trial mode behavior while developing your game,
            // uncomment this line:
            //Guide.SimulateTrialMode = true;

        } // End of the constructor

        #endregion

        #region Initialization

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // TODO: Add your initialization logic here

            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // TODO: use this.Content to load your game content here
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        #endregion

        #region Update

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            //if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
            //    this.Exit();

            // Update the game.
            base.Update(gameTime);

            // Measure our framerate.
            elapsedTime += gameTime.ElapsedGameTime;
            if (elapsedTime > TimeSpan.FromSeconds(1))
            {
                elapsedTime -= TimeSpan.FromSeconds(1);
                frameRate = frameCounter;
                frameCounter = 0;
            }

        } // End of the Update method

        #endregion

        #region Draw

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);

            // Measure our framerate.
            frameCounter++;

            // The real drawing happens inside the screen manager component.
            base.Draw(gameTime);

        } // End of the Draw method

        #endregion

    } // End of the class

} // End of the namespace
