﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using AvatarBlockWar.ParticleEngine;

namespace AvatarBlockWar.ParticleEffects
{
    /// <summary>
    /// This class represent a blood effect
    /// </summary>
    public class BloodEffect : ParticleEffect
    {
        #region Constructors

        /// <summary>
        /// Create a new blood effect
        /// </summary>
        /// <param name="content"></param>
        /// <param name="graphicsDevice"></param>
        public BloodEffect(ContentManager content, GraphicsDevice graphicsDevice)
            : base(content, graphicsDevice)
        {

            // Create a new particle settings object.
            this.settings = new ParticleSettings();

            // Change the settings for the particle settings object.
            this.settings.TextureName = "EffectTextures/bubbleEffect";
            this.settings.MaxParticles = 100;
            this.settings.Duration = TimeSpan.FromSeconds(4);
            this.settings.DurationRandomness = 1;
            this.settings.MinHorizontalVelocity = 0;
            this.settings.MaxHorizontalVelocity = 20;
            this.settings.MinVerticalVelocity = -20;
            this.settings.MaxVerticalVelocity = -5;
            this.settings.EndVelocity = 0;
            this.settings.MinColor = Color.White;
            this.settings.MaxColor = Color.White;
            this.settings.MinRotateSpeed = -1;
            this.settings.MaxRotateSpeed = 1;
            this.settings.MinStartSize = 10;
            this.settings.MaxStartSize = 20;
            this.settings.MinEndSize = 1;
            this.settings.MaxEndSize = 10;

            // Make the blood fall to the ground.
            settings.Gravity = new Vector3(0, -10, 0);

            // Use additive blending.
            this.settings.BlendState = BlendState.AlphaBlend;

            // Create a new particle system.
            this.particleSystem = new ParticleSystem(content, graphicsDevice, this.settings);

        } // End of the constructor

        #endregion

    } // End of the class

} // End of the namespace
