﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using AvatarBlockWar.ParticleEngine;

namespace AvatarBlockWar.ParticleEffects
{
    /// <summary>
    /// This class represent a shot effect for a assault rifle on a enemy
    /// </summary>
    public class EnemyRifleShotEffect : ParticleEffect
    {

        #region Constructors

        /// <summary>
        /// Create a new enemy rifle shot effect
        /// </summary>
        /// <param name="content"></param>
        /// <param name="graphicsDevice"></param>
        public EnemyRifleShotEffect(ContentManager content, GraphicsDevice graphicsDevice)
            : base(content, graphicsDevice)
        {

            // Create a new particle settings object.
            this.settings = new ParticleSettings();

            // Change the settings for the particle settings object.
            this.settings.TextureName = "EffectTextures/fireShotEffect";
            this.settings.MaxParticles = 100;
            this.settings.Duration = TimeSpan.FromSeconds(0.4f);
            this.settings.DurationRandomness = 0;
            this.settings.MinHorizontalVelocity = 0;
            this.settings.MaxHorizontalVelocity = 0;
            this.settings.MinVerticalVelocity = 0;
            this.settings.MaxVerticalVelocity = 0;
            this.settings.EndVelocity = 0;
            this.settings.MinColor = Color.White;
            this.settings.MaxColor = Color.White;
            this.settings.MinRotateSpeed = 1;
            this.settings.MaxRotateSpeed = 1;
            this.settings.MinStartSize = 10;
            this.settings.MaxStartSize = 10;
            this.settings.MinEndSize = 10;
            this.settings.MaxEndSize = 10;

            // Shots shall not fall to the ground
            this.settings.Gravity = new Vector3(0, 0, 0);

            // Use additive blending.
            this.settings.BlendState = BlendState.AlphaBlend;

            // Create a new particle system.
            this.particleSystem = new ParticleSystem(content, graphicsDevice, this.settings);

        } // End of the constructor

        #endregion

    } // End of the class

} // End of the namespace
