﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using AvatarBlockWar.ParticleEngine;

namespace AvatarBlockWar.ParticleEffects
{
    /// <summary>
    /// This class represent a particle effect
    /// </summary>
    public abstract class ParticleEffect
    {
        #region Variables

        // A reference to a particle system
        public ParticleSystem particleSystem;

        // Particle settings
        public ParticleSettings settings;

        // A reference to a graphics device
        public GraphicsDevice graphicsDevice;

        #endregion

        #region Constructors

        /// <summary>
        /// Create a new PlayerShotEffect
        /// </summary>
        /// <param name="content"></param>
        /// <param name="graphicsDevice"></param>
        public ParticleEffect(ContentManager content, GraphicsDevice graphicsDevice)
        {
            // Set the graphicsDevice
            this.graphicsDevice = graphicsDevice;

        } // End of the constructor

        #endregion

        #region Methods

        /// <summary>
        /// Add particles
        /// </summary>
        /// <param name="numberOfParticles"></param>
        /// <param name="position"></param>
        public void AddParticles(int numberOfParticles, Vector3 position, Vector3 direction)
        {
            // Add a number of particles
            for (int i = 0; i < numberOfParticles; i++)
            {
                // Add particle, speed of five
                this.particleSystem.AddParticle(position, direction);
            }

        } // End of the AddParticles method.

        #endregion

        #region Draw

        /// <summary>
        /// Draw the effect.
        /// </summary>
        /// <param name="gameTime"></param>
        /// <param name="view"></param>
        /// <param name="projection"></param>
        /// <param name="position"></param>
        public virtual void DrawEffect(GameTime gameTime, Matrix view, Matrix projection)
        {
            // Update the particle system
            this.particleSystem.Update(gameTime);

            // Set the camera
            this.particleSystem.SetCamera(view, projection);

            // Draw
            this.particleSystem.Draw(gameTime, this.graphicsDevice);

        } // End of the DrawEffect method
        
        #endregion

    } // End of the class

} // End of the namespace
