﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using AvatarBlockWar.Tools;
using AudioEngine;

namespace AvatarBlockWar.PlayerProfiles
{
    public static class StaticPlayerProfileMethods
    {
        #region Methods

        /// <summary>
        /// A static method to get a random start position for a player.
        /// </summary>
        /// <returns name="startPosition">A 3D position</returns>
        public static Vector3 getRandomStartPosition()
        {
            // Variables
            Vector3 startPosition = Vector3.Zero;
            Random rndGenerator = new Random();
            int randomValueX = 0;
            int randomValueZ = 0;

            // The startposition can be anywhere on the map.
            randomValueX = (int)(rndGenerator.NextDouble() * 9940) + 40;
            randomValueZ = (int)(rndGenerator.NextDouble() * 9940) + 40;

            // Set the start position.
            startPosition = new Vector3(randomValueX, 100, randomValueZ);
            //startPosition = new Vector3(100, 100, 100);

            // Return the startposition.
            return startPosition;

        } // End of the getRandomStartPosition

        /// <summary>
        /// Check if we should add a bullet.
        /// </summary>
        /// <param name="gameTime"></param>
        /// <param name="player"></param>
        /// <param name="lookUpDown"></param>
        /// <param name="heightOverPlayersFeet"></param>
        public static void AddBullet(GameTime gameTime, PlayerProfile player, Vector3 lookUpDown, 
            Vector3 heightOverPlayersFeet, AudioManager audioManager)
        {
            // Check if we should add a shot
            if (player.shotDelayCounter <= 0 && player.isShooting)
            {
                // Add a bullet
                player.bullet = new Bullet(player.playerPosition + heightOverPlayersFeet, player.playerDirection + lookUpDown);

                // Reset the shot countdown
                player.shotDelayCounter = player.tools[player.currentTool].shotDelay;

                // Add a shot effect
                if (player is HumanPlayerProfile)
                {
                    Vector3 effectPosition = player.playerPosition + heightOverPlayersFeet + ((player.playerDirection + lookUpDown) * 10);
                    player.tools[player.currentTool].playerShotEffect.AddParticles(30, effectPosition, Vector3.Zero);
                }

                // Add a enemy shot effect
                Vector3 position = player.playerPosition + new Vector3(0, 57.5f, 0) + player.playerDirection * 40;
                player.playerModel.shotEffect.AddParticles(50, position, player.playerDirection);

                // Play the shot sound
                player.tools[player.currentTool].PlayShotSound(audioManager, player);

            }
            else
            {
                // Subract game time from the shotDelayCounter
                player.shotDelayCounter -= gameTime.ElapsedGameTime.Milliseconds;
            }

        } // End of the AddBullet method

        #endregion

    } // End of the class

} // End of the namespace
