﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.GamerServices;
using AvatarBlockWar.Screens.MenuScreens;
using AvatarBlockWar.Screens.NetworkScreens;
using AvatarBlockWar.Screens.GameScreens;
using AvatarBlockWar.DataStorage;
using ScreenManagement;
using Networking;

namespace AvatarBlockWar.Screens.LobbyScreens
{
    /// <summary>
    /// This class represent a lobby screen for a local game
    /// </summary>
    public class LocalGameLobbyScreen : LobbyScreen
    {
        #region Constructors

        /// <summary>
        /// Create a new lobby screen for a local game
        /// </summary>
        /// <param name="networkSession"></param>
        public LocalGameLobbyScreen(NetworkSession networkSession)
            : base(networkSession)
        {

        } // End of the constructor

        #endregion

        #region Update

        /// <summary>
        /// Update the lobby screen.
        /// </summary>
        public override void Update(GameTime gameTime, bool otherScreenHasFocus, bool coveredByOtherScreen)
        {
            base.Update(gameTime, otherScreenHasFocus, coveredByOtherScreen);

            if (!IsExiting)
            {
                if (networkSession.SessionState == NetworkSessionState.Playing)
                {

                    // Check if we should leave the lobby and begin gameplay.
                    // We pass null as the controlling player, because the networked
                    // gameplay screen accepts input from any local players who
                    // are in the session, not just a single controlling player.
                    LoadingScreen.Load(ScreenManager, true, null, new GameplayScreen(this.networkSession, 1, Program.selectedMapName));

                }
                else if (networkSession.IsHost && networkSession.IsEveryoneReady)
                {
                    // The host checks whether everyone has marked themselves
                    // as ready, and starts the game in response.
                    networkSession.StartGame();
                }

            } // End of if (!IsExiting)

        } // End of the update method.

        #endregion

    } // End of the class

} // End of the namespace
