﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.GamerServices;
using AvatarBlockWar.Screens.GameScreens;
using ScreenManagement;
using MapObjects;

namespace AvatarBlockWar.Screens.MenuScreens
{
    /// <summary>
    /// This class represent menu entries to create a new map and to load an old map.
    /// </summary>
    public class BuildMapScreen : MenuScreen
    {
        #region Constructors

        /// <summary>
        /// Create a new build map screen.
        /// </summary>
        public BuildMapScreen()
            : base(Resources.BuildMap)
        {
            
            // Create our menu entries.
            MenuEntry newMapMenuEntry = new MenuEntry("New map");
            MenuEntry loadMapMenuEntry = new MenuEntry("Edit map");
            MenuEntry deleteMapMenuEntry = new MenuEntry("Delete map");
            MenuEntry backMenuEntry = new MenuEntry(Resources.Back);

            // Hook up menu event handlers.
            newMapMenuEntry.Selected += NewMapMenuEntryMenuEntrySelected;
            loadMapMenuEntry.Selected += LoadMapMenuEntrySelected;
            deleteMapMenuEntry.Selected += DeleteMapMenuEntrySelected;
            backMenuEntry.Selected += OnCancel;

            // Add entries to the menu.
            menuEntries.Add(newMapMenuEntry);
            menuEntries.Add(loadMapMenuEntry);
            menuEntries.Add(deleteMapMenuEntry);
            menuEntries.Add(backMenuEntry);

        } // End of the constructor

        #endregion

        #region Event Handlers

        /// <summary>
        /// Event handler for when the new map menu entry is selected.
        /// </summary>
        private void NewMapMenuEntryMenuEntrySelected(object sender, PlayerIndexEventArgs e)
        {
            // Ask the user to enter a name for the map.
            Guide.BeginShowKeyboardInput(e.PlayerIndex, "New map", "Enter a name for the map", "new map", new AsyncCallback(OnEndShowKeyboardInput), null);
        
        } // End of the NewMapMenuEntryMenuEntrySelected method.

        /// <summary>
        /// Creates a new map when the user has entered a name for the map.
        /// </summary>
        /// <param name="result"></param>
        private void OnEndShowKeyboardInput(IAsyncResult result)
        {
            // Get the map name
            string mapName = Guide.EndShowKeyboardInput(result);

            // Add the gameplay screen
            LoadingScreen.Load(ScreenManager, true, ControllingPlayer.Value, new GameplayScreen(null, 0, mapName));

        } // End of the OnEndShowKeyboardInput

        /// <summary>
        /// Event handler for when the load map menu entry is selected.
        /// </summary>
        private void LoadMapMenuEntrySelected(object sender, PlayerIndexEventArgs e)
        {
            // Add the EditMapScreen
            ScreenManager.AddScreen(new EditMapScreen(), e.PlayerIndex);
        }

        /// <summary>
        /// Event handler for when the delete map menu entry is selected.
        /// </summary>
        private void DeleteMapMenuEntrySelected(object sender, PlayerIndexEventArgs e)
        {
            // Add the DeleteMapScreen
            ScreenManager.AddScreen(new DeleteMapScreen(), e.PlayerIndex);
        }

        #endregion

    } // End of the class

} // End of the namespace
