﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using AvatarBlockWar.ParticleEffects;
using AudioEngine;

namespace AvatarBlockWar.Tools
{
    /// <summary>
    /// This class represent a hammer
    /// </summary>
    public class Hammer : Tool
    {
        #region Constructors

        /// <summary>
        /// Create a new hammer
        /// </summary>
        /// <param name="tool"></param>
        public Hammer(Model tool, PistolShotEffect shotEffect)
            : base(tool)
        {
            // Set values for instance variables
            this.shotDelay = 100;
            this.healthDamage = 10;

            // Create the pistol shot effect
            this.playerShotEffect = shotEffect;

        } // End of the constructor

        #endregion

        #region Draw

        /// <summary>
        /// Draw the tool
        /// </summary>
        /// <param name="view"></param>
        /// <param name="projection"></param>
        public override void DrawTool(Matrix view, Matrix projection)
        {

            // Get the world variable for the camera
            Matrix cameraWorld = Matrix.Invert(view);

            // Create the world for the hammer
            Matrix toolWorld = Matrix.CreateScale(0.09f) * cameraWorld;
            toolWorld.Translation += (cameraWorld.Forward * 2f) + (cameraWorld.Right * 1.5f) + (cameraWorld.Up * -3f);

            // Loop through each mesh in the model and draw it.
            foreach (ModelMesh mesh in this.tool.Meshes)
            {
                foreach (BasicEffect effect in mesh.Effects)
                {
                    effect.World = toolWorld;
                    effect.View = view;
                    effect.Projection = projection;

                    effect.EnableDefaultLighting();
                }

                mesh.Draw();
            }

        } // End of the DrawTool method.

        #endregion

        #region Methods

        /// <summary>
        /// Play a shot sound
        /// </summary>
        /// <param name="audioManager"></param>
        /// <param name="audioEmitter"></param>
        public override void PlayShotSound(AudioManager audioManager, IAudioEmitter audioEmitter)
        {
            // Do nothing

        } // End of the PlayShotSound method

        #endregion

    } // End of the class

} // End of the namespace
