﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content;
using AvatarBlockWar.ParticleEffects;
using AudioEngine;

namespace AvatarBlockWar.Tools
{
    /// <summary>
    /// This abstract class represent a tool that is placed under the camera.
    /// </summary>
    public abstract class Tool
    {
        #region Variables

        protected Model tool;

        // Shooting
        public int shotDelay;
        public byte healthDamage;

        // Playershot effect
        public ParticleEffect playerShotEffect;

        #endregion

        #region Constructors

        /// <summary>
        /// Create a tool
        /// </summary>
        /// <param name="tool"></param>
        public Tool(Model tool)
        {
            // Set values for instance variables
            this.tool = tool;

        } // End of the constructor

        #endregion

        #region Draw

        /// <summary>
        /// Draw the tool in front of the camera
        /// </summary>
        /// <param name="view"></param>
        /// <param name="projection"></param>
        public abstract void DrawTool(Matrix view, Matrix projection);

        #endregion

        #region Methods

        /// <summary>
        /// Play a shooting sound.
        /// </summary>
        /// <param name="audioManager"></param>
        /// <param name="audioEmitter"></param>
        public abstract void PlayShotSound(AudioManager audioManager, IAudioEmitter audioEmitter);

        #endregion

    } // End of the class

} // End of the namespace
